News
====

1.5
---
*Release date: 2026-03-15*

* Switched from poetry to uv for package management
* Added type hints to entire codebase
* Added __slots__ to Storage class for memory optimization
* Enabled additional ruff rules (B, SIM, PT, PERF, PTH, T2, ERA)
* Added comprehensive unit tests (50 tests, AI gen)
* Added RST validation with restructuredtext-lint
* Added doctests for json_load_storage and json_dump_storage
* Converted HACKING.txt to RST format

1.4
---
*Release date: 2024-09-03*

* Misc non code updates
* ruff auto formatting
* Fixed errors and warnings reported by ruff and mypy

1.3
---
*Release date: 2020-12-16*

* Removed support for Python 2.x
* Switched from setup.py to poetry

1.2
---
*Release date: 2016-08-26*

* Removed a double normalization

1.1
---
*Release date: 2014-07-01*

* added items() == iteritems() to storage for Py3 style compat.

1.0.2
-----

* More doctests, almost full coverage.
* Fixed bug relating to normalization
* get_doc now returns a denormalized copy of the internal dict

1.0.1
-----

*Release date: 2014-06-18*

* include the code in the package...

1.0
---

*Release date: 2014-06-18*

 storage was previusly a part of hcs_utils (hcs_utils.storage)

